.. _debops_policy:

DebOps Guidelines and Policies
==============================

.. toctree::
   :maxdepth: 1

   policy/organizational-structure
   policy/distributed-development
   policy/code-signing-policy
   policy/security-policy

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
